@@ -21,13 +21,13 @@ static inline void ch_time_and_mod_link(const struct stat *stat_buf, const CPInf
 {
 	errno = 0;
 /*
-	if(lchown(cpinfo->to, stat_buf->st_uid, stat_buf->st_gid) == -1)
+	if(lchown(cpinfo->dst, stat_buf->st_uid, stat_buf->st_gid) == -1)
 	{
 		print_error("lchown", __FILE__, __LINE__, cpdd);
 	}
 */
 
-	lchown(cpinfo->to, stat_buf->st_uid, stat_buf->st_gid);
+	lchown(cpinfo->dst, stat_buf->st_uid, stat_buf->st_gid);
 
 	time_s[0].tv_sec = stat_buf->st_atime;
 	time_s[1].tv_sec = stat_buf->st_mtime;
@@ -38,10 +38,10 @@ static inline void ch_time_and_mod_link(const struct stat *stat_buf, const CPInf
 /* time_s[1].tv_nsec = stat_buf->st_mtimensec; */
 
 	/* 第四引数は0かAT_SYMLINK_NOFOLLOW */
-	if(utimensat(AT_FDCWD, cpinfo->to, time_s, AT_SYMLINK_NOFOLLOW) == -1)
+	if(utimensat(AT_FDCWD, cpinfo->dst, time_s, AT_SYMLINK_NOFOLLOW) == -1)
 	{
 		print_error("utimensat", __FILE__, __LINE__, cpdd);
-		fprintf(stderr, "ファイル情報変更エラーです (%s) \n", cpinfo->to);
+		fprintf(stderr, "ファイル情報変更エラーです (%s) \n", cpinfo->dst);
 	}
 }
 
