@@ -129,7 +129,7 @@ static inline void set_same_or_different(const VList *, const char *, const char
 \
 		file_list = dir_traverse(file_list, cpinfo, oparg, sdir, cpdd);\
 \
-		if((src_current_flag == false) && (cpinfo->write == true))\
+		if((src_current_flag == false) && (cpinfo->d_para == WRITE))\
 		{\
 			ch_time_and_mod_dir(cpinfo, stat_buf, cpdd);\
 		}\
@@ -424,8 +424,7 @@ RData * check_target(OPArg *oparg, VList *drive_list, SDir *sdir)
 *******************************************************************************/
 #define DO_NOT_OVERWRITE_FLAG \
 {\
-	cpinfo->write = false;\
-	cpinfo->skip = true;\
+	cpinfo->d_para = SKIP;\
 }
 
 #define FILE_WRITE_OR_CREATE_LINK_OVERWRITE \
@@ -696,7 +695,7 @@ struct stat * make_directory(CPInfo *cpinfo, OPArg *oparg, CPDD *cpdd)
 	}
 	else if(mkdir(cpinfo->dst, 0755) == -1)
 	{
-		cpinfo->write = false;
+		cpinfo->d_para = INITIAL;
 
 		if((errno != EEXIST) && (errno != 0))
 		{
@@ -712,7 +711,7 @@ struct stat * make_directory(CPInfo *cpinfo, OPArg *oparg, CPDD *cpdd)
 			fflush(stdout);
 		}
 
-		cpinfo->write = true;
+		cpinfo->d_para = WRITE;
 		cpdd->mk_dir_count++;
 	}
 
@@ -756,7 +755,7 @@ struct stat * make_directory(CPInfo *cpinfo, OPArg *oparg, CPDD *cpdd)
 	file_list = append_list(file_list, (void *)cpinfo);\
 	/* 再帰 */ \
 	file_list = dir_traverse(file_list, cpinfo, oparg, sdir, cpdd);\
-	if(cpinfo->write == true) {ch_time_and_mod_dir(cpinfo, stat_buf, cpdd); }\
+	if(cpinfo->d_para == WRITE) {ch_time_and_mod_dir(cpinfo, stat_buf, cpdd); }\
 }
 
 /*******************************************************************************
@@ -864,10 +863,9 @@ static inline CPInfo * cpinfo_malloc(void)
 	cpinfo->src = NULL;
 	cpinfo->dst = NULL;
 	cpinfo->dstfs = NULL;
-/*	cpinfo->src_type = */
 	cpinfo->copy_mode = SAME;
-	cpinfo->write = false;
-	cpinfo->skip = false;
+	cpinfo->d_para = INITIAL;
+	cpinfo->s_para = DEFAULT;
 	cpinfo->hash_check = false;
 	cpinfo->file_test = false;
 	cpinfo->verify_md5 = NULL;
