@@ -167,7 +167,7 @@ void compare_hash(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cp
 				fprintf(stderr, "ハッシュ値が一致しませんでした、%sを削除します\n", cpinfo->dst);
 				print_error("NODATA", __FILE__, __LINE__, cpdd);
 				write_log_hash_check(cpinfo, ssrc, ddst, sdir, cpdd, false);
-				cpinfo->write = false;
+				cpinfo->d_para = DELETE;
 
 				errno = 0;
 				if(unlink(cpinfo->dst) == -1)
