@@ -16,7 +16,7 @@
 	print_error("unlink", __FILE__, __LINE__, cpdd);\
 	fprintf(stderr, "対象を削除出来ませんでした (%s) \n", cpinfo->dst);\
 	fprintf(stderr, "シンボリックリンクを作成できません\n");\
-	cpinfo->write = false;
+	cpinfo->d_para = INITIAL;
 
 /* 関数プロトタイプ */
 static inline void create_symboliclink(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd) __attribute__((always_inline));
@@ -134,7 +134,10 @@ static inline void create_symboliclink(const OPArg *oparg, CPInfo *cpinfo, CPDD
 		check = false;
 	}
 
-	cpinfo->write = check;
+	if(check == true)
+	{
+		cpinfo->d_para = WRITE;
+	}
 }
 
 /*******************************************************************************
