@@ -4,7 +4,12 @@
 */
 #define _GNU_SOURCE
 
+#ifdef _DEBUG_FLAG
+#define USE_O_DIRECT_SIZE 1
+#endif
+#ifndef _DEBUG_FLAG
 #define USE_O_DIRECT_SIZE 1024 * 1024 * 1
+#endif
 
 #include "ch_time_and_mod.h" // inline
 #include "compare_hash.h"
@@ -61,7 +66,7 @@
 	{\
 		compare_hash(oparg, sdir, cpinfo, cpdd);\
 	}\
-	else if(cpinfo->skip == false)\
+	else \
 	{\
 		fprintf(stderr, "ファイルのオープンに失敗しているため、コンペアをスキップします\n");\
 		fprintf(stderr, "src : %s\n", cpinfo->src);\
@@ -194,10 +199,20 @@ void read_write(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd
 				((tmp[0] == 'o') && (tmp[1] == 'c') && (tmp[2] == 'f') && (tmp[2] == 's') && (tmp[2] == '2'))
 			)
 			{
+				#ifdef _DEBUG_FLAG
+					puts("fallocate_support");
+					fflush(stdout);
+				#endif
+
 				fallocate_support = true;
 			}
 			else if((tmp[0] == 'x') && (tmp[1] == 'f') && (tmp[2] == 's'))
 			{
+				#ifdef _DEBUG_FLAG
+					puts("fallocate_support (xfs)");
+					fflush(stdout);
+				#endif
+
 				fallocate_support = true;
 				o_direct_write_flag = true;
 			}
@@ -298,7 +313,7 @@ void read_write(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd
 					}
 					else
 					{
-						cpinfo->skip = true;
+						cpinfo->d_para = SKIP;
 					}
 				}
 				else
@@ -309,7 +324,7 @@ void read_write(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd
 					}
 					else
 					{
-						cpinfo->skip = true;
+						cpinfo->d_para = SKIP;
 					}
 				}
 			}
@@ -321,6 +336,14 @@ void read_write(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd
 		}
 	}
 
+	#ifdef _DEBUG_FLAG
+		if(o_direct_open_dst == true)
+		{
+			puts("o_direct_open_dst = true");
+			fflush(stdout);
+		}
+	#endif
+
 	/*
 	 * ファイルシステムがfallocateをサポートしている場合、それを実行して領域を確保する。
 	 * 
@@ -330,6 +353,11 @@ void read_write(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd
 	*/
 	if((src_size_local > 0) && (open_dst == true) && (fallocate_support == true))
 	{
+		#ifdef _DEBUG_FLAG
+			puts("fallocate");
+			fflush(stdout);
+		#endif
+
 		/* Ubuntu 11.04だとfallocateの第二引数は FALLOC_FL_KEEP_SIZE と FALLOC_FL_PUNCH_HOLE の二つ。linux/falloc.h のincludeが必要。 */
 		if(fallocate(idst, FALLOC_FL_KEEP_SIZE, 0, src_size_local) == -1)
 		{
@@ -376,6 +404,11 @@ void read_write(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd
 			}
 			else
 			{
+				#ifdef _DEBUG_FLAG
+					puts("mw_small_direct");
+					fflush(stdout);
+				#endif
+
 				mw_small_direct(cpinfo, cpdd, &state, digest, &thread_argument, &t_verify);
 			}
 		}
@@ -387,6 +420,11 @@ void read_write(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd
 			}
 			else
 			{
+				#ifdef _DEBUG_FLAG
+					puts("mw_thread_direct");
+					fflush(stdout);
+				#endif
+
 				mw_thread_direct(oparg, cpinfo, cpdd, &state, digest, &thread_argument, &t_verify);
 			}
 		}
@@ -398,6 +436,11 @@ void read_write(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd
 			}
 			else
 			{
+				#ifdef _DEBUG_FLAG
+				puts("mw_big_direct");
+				fflush(stdout);
+				#endif
+
 				mw_big_direct(cpinfo, cpdd, &state, digest, &thread_argument, &t_verify);
 			}
 		}
@@ -477,11 +520,11 @@ void read_write(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd
 
 	if((open_src == true) && (open_dst == true) && (src_size_local <= total_write_local))
 	{
-		cpinfo->write = true;
+		cpinfo->d_para = WRITE;
 	}
 	else
 	{
-		cpinfo->write = false;
+		cpinfo->d_para = INITIAL;
 	}
 
 	if(oparg->CHECK_MODE == BEFORE)
@@ -551,7 +594,7 @@ inline static void mw_small(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *state, md5_
 		total_read_local = src_size_local;
 
 		errno = 0;
-		if(madvise(buf[0], src_size_local, MADV_SEQUENTIAL) == -1)
+		if(madvise(buf[0], src_size_local, MADV_WILLNEED) == -1)
 		{
 			print_error("madvise", __FILE__, __LINE__, cpdd);
 		}
@@ -642,7 +685,7 @@ inline static void mw_small_direct(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *stat
 			total_read_local += read_size;
 
 			errno = 0;
-			if(madvise(buf[0], read_size, MADV_SEQUENTIAL) == -1)
+			if(madvise(buf[0], read_size, MADV_WILLNEED) == -1)
 			{
 				print_error("madvise", __FILE__, __LINE__, cpdd);
 			}
@@ -733,7 +776,7 @@ inline static void mw_big(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *state, md5_by
 			total_read_local += read_size;
 
 			errno = 0;
-			if(madvise(buf[0], read_size, MADV_SEQUENTIAL) == -1)
+			if(madvise(buf[0], read_size, MADV_WILLNEED) == -1)
 			{
 				print_error("madvise", __FILE__, __LINE__, cpdd);
 			}
@@ -851,7 +894,7 @@ inline static void mw_big_direct(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *state,
 			total_read_local += read_size;
 
 			errno = 0;
-			if(madvise(buf[0], read_size, MADV_SEQUENTIAL) == -1)
+			if(madvise(buf[0], read_size, MADV_WILLNEED) == -1)
 			{
 				print_error("madvise", __FILE__, __LINE__, cpdd);
 			}
@@ -1176,7 +1219,6 @@ static void * read_thread_func(void *unknown)
 	else
 	{
 		errno = 0;
-		/* マルチスレッドの場合、MADV_SEQUENTIALよりもMADV_WILLNEEDの方が速い、ような気がする。 */
 		if(madvise(buf[i], read_size, MADV_WILLNEED) == -1)
 		{
 			/* このcpddに意味はない。print_errorの引数用。 */
