@@ -3,12 +3,6 @@
 
 #include <sys/types.h>
 
-typedef enum copy_mode_flag
-{
-	SAME,
-	DIFFERENT,
-} CMF;
-
 typedef enum copy_file_type
 {
 	REGULAR,
@@ -16,15 +10,39 @@ typedef enum copy_file_type
 	DIRECTORY,
 } CFT;
 
+typedef enum copy_mode_flag
+{
+	SAME,
+	DIFFERENT,
+} CMF;
+
+typedef enum dst_parameter
+{
+	WRITE,
+	SKIP,
+	DELETE,
+
+	INITIAL,
+} DPT;
+
+typedef enum src_parameter
+{
+	/* 同じ名前は使えないのでDELETEではなくUNLINKにした */
+	UNLINK,
+
+	/* 同じ名前は使えないのでINITIALではなくDEFAULTにした */
+	DEFAULT,
+} SPT;
+
 typedef struct copy_infomation
 {
 	char *src;
 	char *dst;
 	char *dstfs;
-	enum copy_file_type src_type;
-	enum copy_mode_flag copy_mode;
-	_Bool write;
-	_Bool skip;
+	CFT src_type;
+	CMF copy_mode;
+	DPT d_para;
+	SPT s_para;
 	_Bool hash_check;
 	_Bool file_test;
 	char *verify_md5;
