@@ -48,8 +48,8 @@ typedef struct option_and_argument
 	enum option_flag V;
 	enum option_flag EFFECT;
 	int argc; /* 引数の数。main()の仮引数を入れる。 */
-	int fromindex; /* getoptのoptindを入れる */
-	int toindex; /* argv[argc - 1] */
+	int src_index; /* getoptのoptindを入れる */
+	int dst_index; /* argv[argc - 1] */
 	int arg_count; /* コピー元の数 */
 	char **argv; /* main()の仮引数を入れる。 */
 } OPArg;
